@@ -4,6 +4,7 @@
 #include "branch-container.h"
 
 #include "branchitem.h"
+#include "log.h"
 #include "flag-container.h"
 #include "flag.h"
 #include "flagrow-container.h"
@@ -284,14 +285,6 @@ void BranchContainer::addToBranchesContainer(BranchContainer *bc)
         branchesContainer->addContainer(bc);
 }
 
-void BranchContainer::updateImagesContainer()
-{
-    if (imagesContainer && imagesContainer->childItems().count() == 0) {
-        delete imagesContainer;
-        imagesContainer = nullptr;
-    }
-}
-
 void BranchContainer::createOuterContainer()
 {
     if (!outerContainer) {
@@ -372,6 +365,7 @@ void BranchContainer::updateTransformations()
 
 void BranchContainer::updateChildrenStructure()
 {
+    logDebug("BC::updateChildrenStructure of " + info());
     if (branchesContainerLayoutInt == List) {
         if (!listContainer) {
             // Create and setup a listContainer *below* the ornamentsContainer
@@ -610,6 +604,14 @@ void BranchContainer::updateChildrenStructure()
     }
 }
 
+void BranchContainer::updateImagesContainer()
+{
+    if (imagesContainer && imagesContainer->childItems().count() == 0) {
+        delete imagesContainer;
+        imagesContainer = nullptr;
+    }
+}
+
 void BranchContainer::updateImagesContainerParent()
 {
     if (outerContainer)
