@@ -13,13 +13,13 @@ class ConfluenceUser {
     ConfluenceUser &operator=(const ConfluenceUser &) = default;
     void copy(const ConfluenceUser &);
     void setTitle(const QString &s);
-    void setURL(const QString &s);
+    void setUrl(const QString &s);
     void setUserName(const QString &s);
     void setDisplayName(const QString &s);
     void setUserKey(const QString &s);
 
     QString getTitle();
-    QString getURL();
+    QString getUrl();
     QString getUserName();
     QString getDisplayName();
     QString getUserKey();
