@@ -7,6 +7,7 @@
 #include "tmp-parent-container.h"
 
 #include "branchitem.h"
+#include "log.h"
 #include "misc.h"
 
 #define qdbg() qDebug().nospace().noquote()
@@ -22,6 +23,9 @@ Container::Container()
 Container::~Container()
 {
     //qdbg() << "Destr Container" << info() << this;
+
+    // The destructor of QGraphicsItem will implicitely remove the container from 
+    // parents set of children
 }
 
 void Container::copy(Container *other)
@@ -157,7 +161,7 @@ QString Container::info (const QString &prefix)
         //+ QString(" a: %1").arg(qRound(rotation()))
         //+ QString(" scenePos: %1").arg(toS(scenePos(), 0))
         //+ QString(" pos: %1").arg(toS(pos(), 0))
-        //+ QString(" rect: %1").arg(toS(rect(), 0))
+        + QString(" rect: %1").arg(toS(rect(), 0))
         //+ QString(" sceneRect: %1").arg(toS(mapRectToScene(rect()), 0))
         //+ QString(" vis: %1").arg(isVisible());
         + QString(" Layout: %1").arg(layoutString())
@@ -445,10 +449,17 @@ QPointF Container::alignTo(PointName ownPointName, Container* targetContainer, P
     return mapFromItem(targetContainer, targetContainer->pointByName(targetPointName)) - pointByName(ownPointName);
 }
 
+#include <QMessageBox>  // FIXME-2 debugging
 void Container::addContainer(Container *c, int z)
 {
     if (childContainers().contains(c)) return;
 
+    if (!c) {   // FIXME-2 debugging
+        logDebug("Container::addContainer  adding 0 to " + info() + " would crash");
+        QMessageBox::warning(0, "Warning", "Would have crashed now in ::addContainer");
+        return;
+    }
+
     c->setParentItem(this);
     if (z > 0)
         // Update z of container
