@@ -37,6 +37,12 @@ FindResultWidget::FindResultWidget(QWidget *)
     connect(a, SIGNAL(triggered()), this, SLOT(closeWindow()));
     addAction(a);
 
+    a = new QAction("Switch focus", this);
+    a->setShortcut(Qt::Key_Tab);                // Switch focus between QComboBox and QTreeView
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    connect(a, SIGNAL(triggered()), this, SLOT(switchFocus()));
+    addAction(a);
+
     QVBoxLayout *mainLayout = new QVBoxLayout;
 
     mainLayout->addWidget(view);
@@ -54,6 +60,19 @@ FindResultWidget::FindResultWidget(QWidget *)
     connect(resultsModel, SIGNAL(layoutChanged()), view, SLOT(expandAll()));
 }
 
+void FindResultWidget::switchFocus()
+{
+    if (view->hasFocus())
+        setFocus();
+    else
+        view->setFocus();
+}
+
+void FindResultWidget::setFocus()
+{
+    findControlsWidget->setFocus();
+}
+
 void FindResultWidget::addItem(TreeItem *ti)
 {
     if (ti) {
@@ -98,7 +117,7 @@ void FindResultWidget::popup()
 {
     show();
     parentWidget()->show();
-    findControlsWidget->setFocus();
+    view->setFocus();
 }
 
 void FindResultWidget::cancelPressed()
