@@ -60,6 +60,8 @@ class Main : public QMainWindow {
     void fileNew();
     void fileNewCopy();
 
+    void satelliteVisibilityChanged();
+
   protected:
     void closeEvent(QCloseEvent *);
 
@@ -345,22 +347,31 @@ class Main : public QMainWindow {
     bool settingsConfluence();
     bool settingsJIRA();
 
-    void windowShowNoteEditor();
+    void focusMapEditor();
+    void focusNoteEditor();
+    void toggleNoteEditor();
+    void toggleTreeEditors();
     void switchEditors();
-    void windowSetTreeEditorsVisibility(bool);
-    void windowToggleTaskEditor();
-    void windowShowSlideEditors();
-    void windowSetSlideEditorsVisibility(bool);
-    void windowToggleScriptEditor();
-    void windowToggleScriptOutput();
-    void windowToggleHistory();
-    void windowToggleProperty();
-    void windowShowHeadingEditor();
+    void setTreeEditorsVisibility(bool);
+    void focusTaskEditor();
+    void toggleTaskEditor();
+    void toggleSlideEditors();
+    void setSlideEditorsVisibility(bool);
+    void focusScriptEditor();
+    void toggleScriptEditor();
+    void focusScriptOutput();
+    void toggleScriptOutput();
+    void focusHistory();
+    void toggleHistory();
+    void focusProperty();
+    void toggleProperty();
+    void focusHeadingEditor();
+    void toggleHeadingEditor();
     void updateHistory(SimpleSettings &);
-    void windowToggleAntiAlias();
+    void toggleAntiAlias();
     bool isAliased();
     bool hasSmoothPixmapTransform();
-    void windowToggleSmoothPixmap();
+    void toggleSmoothPixmap();
     void clearScriptOutput();
     void updateHeading(const VymText &vt);
     void updateNoteText(const VymText &vt);
@@ -392,8 +403,8 @@ class Main : public QMainWindow {
     bool gotoWindow(const int &n);
 
   private slots:
-    void windowNextEditor();
-    void windowPreviousEditor();
+    void nextEditor();
+    void previousEditor();
     void nextSlide();
     void previousSlide();
 
@@ -482,7 +493,8 @@ class Main : public QMainWindow {
     QList <QColor> quickColors;
 
     QMenu *toolbarsMenu;
-    QMenu *windowsMenu;
+    QMenu *toggleWindowsMenu;
+    QMenu *focusWindowsMenu;
 
     QMenu *branchAddContextMenu;
     QMenu *branchGeometryContextMenu;
@@ -671,15 +683,31 @@ class Main : public QMainWindow {
     QAction *actionFormatLinkStylePolyParabel;
     QAction *actionFormatHideLinkUnselected;
 
+    QAction *actionViewFocusNoteEditor;
     QAction *actionViewToggleNoteEditor;
+
+    QAction *actionViewFocusHeadingEditor;
     QAction *actionViewToggleHeadingEditor;
+
+    QAction *actionViewFocusTaskEditor;
     QAction *actionViewToggleTaskEditor;
+
     QAction *actionViewSwitchEditors;
-    QAction *actionViewShowSlideEditors;
+    QAction *actionViewToggleTreeEditors;
+    QAction *actionViewToggleSlideEditors;
+
+    QAction *actionViewFocusScriptEditor;
     QAction *actionViewToggleScriptEditor;
+
+    QAction *actionViewFocusScriptOutput;
     QAction *actionViewToggleScriptOutput;
+
+    QAction *actionViewFocusHistoryWindow;
     QAction *actionViewToggleHistoryWindow;
+
+    QAction *actionViewFocusPropertyEditor;
     QAction *actionViewTogglePropertyEditor;
+
     QAction *actionViewToggleAntiAlias;
     QAction *actionViewToggleSmoothPixmapTransform;
     QAction *actionViewCenter;
