@@ -8,10 +8,8 @@
 extern Settings settings;
 extern QString vymName;
 
-NoteEditor::NoteEditor(const QString &eName) : TextEditor(eName)
+NoteEditor::NoteEditor(const QString &id, const QString &scope) : TextEditor(id, scope)
 {
-    editorName = eName;
-
     setWindowTitle("");
 
     menuBar()->show();
@@ -29,7 +27,7 @@ VymNote NoteEditor::getNote()
     else
         note.setPlainText(getText());
     note.setFontHint(getFontHint());
-    note.setFilenameHint(getFilenameHint());
+    note.setFileName(fileName());
     return note;
 }
 
@@ -41,5 +39,5 @@ void NoteEditor::setNote(const VymNote &note)
         setPlainText(note.getText());
         setFontHint(note.getFontHint());
     }
-    setFilenameHint(note.getFilenameHint());
+    setFileName(note.fileName());
 }
