@@ -14,6 +14,7 @@
 
 #include "branchitem.h"
 #include "mainwindow.h"
+#include "shortcuts.h"
 #include "task.h"
 #include "taskfiltermodel.h"
 #include "taskmodel.h"
@@ -24,6 +25,8 @@ extern Settings settings;
 extern QMenu *taskContextMenu;
 extern TaskModel *taskModel;
 
+extern Switchboard switchboard;
+
 extern QString editorFocusInStyle;
 
 TaskEditor::TaskEditor(QWidget *)
@@ -111,6 +114,16 @@ TaskEditor::TaskEditor(QWidget *)
     connect(a, SIGNAL(triggered()), this, SLOT(toggleFilterFlags3()));
     actionToggleFilterFlags3 = a;
 
+    // Shortcuts
+    QString shortcutScope = tr("Task Editor", "Shortcut group");
+    switchboard.addScope("TaskEditor", shortcutScope);
+
+    a = new QAction("Close window", this);
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    switchboard.addAction(a, "taskEditorCloseWindow", Qt::CTRL | Qt::Key_D, shortcutScope, "");
+    connect(a, SIGNAL(triggered()), this, SLOT(closeWindow()));
+    view->addAction(a);
+
     // Clone actions defined in MainWindow
     foreach (QAction *qa, mainWindow->taskEditorActions) {
         a = new QAction(this);
@@ -221,6 +234,11 @@ TaskEditor::~TaskEditor()
     }
 }
 
+void TaskEditor::setFocus()
+{
+    view->setFocus();
+}
+
 void TaskEditor::setMapName(const QString &n)
 {
     currentMapName = n;
@@ -300,8 +318,7 @@ void TaskEditor::showSelection()
     QModelIndexList list = view->selectionModel()->selectedIndexes();
     if (list.count() > 0)
         // Usually whole row is selected, so just go for first cell
-        view->scrollTo(taskModel->index(taskModel->getTask(list.first())),
-                       QAbstractItemView::EnsureVisible);
+        view->scrollTo(list.first(), QAbstractItemView::EnsureVisible);
 }
 
 bool TaskEditor::select(Task *task)
@@ -426,6 +443,8 @@ void TaskEditor::selectionChanged(const QItemSelection &selected,
             if (m != mainWindow->currentModel())
                 mainWindow->gotoModel(m);
         }
+
+        showSelection();
     }
 }
 
@@ -434,6 +453,12 @@ void TaskEditor::contextMenuEvent(QContextMenuEvent *e)
     taskContextMenu->popup(e->globalPos());
 }
 
+void TaskEditor::closeWindow()
+{
+    parentWidget()->hide();
+    emit windowClosed();
+}
+
 void TaskEditor::toggleFilterMap() { setFilterMap(); }
 
 void TaskEditor::toggleFilterActive() { setFilterActive(); }
