@@ -13,13 +13,14 @@
 #include <QPushButton>
 #include <QPrinter>
 #include <QStatusBar>
-#include <QTextEdit>
 #include <QToolBar>
 
 #include "file.h"
 #include "mainwindow.h"
+#include "my-textedit.h"
 #include "settings.h"
 #include "shortcuts.h"
+#include "url-dialog.h"
 
 extern Main *mainWindow;
 extern Settings settings;
@@ -44,13 +45,16 @@ extern bool debug;
 ///////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////
 
-TextEditor::TextEditor(const QString eName)   // FEATURE #137 insert images with drag & drop
+TextEditor::TextEditor(const QString &id, const QString &scope)   // FEATURE #137 insert images with drag & drop
                            // https://stackoverflow.com/questions/3254652/several-ways-of-placing-an-image-in-a-qtextedit
 {
-    //qDebug() << "TE::constr of " << eName;
+    //qDebug() << "TE::constr of " << id << scope;
+    editorId = id;
+    shortcutScope = scope;
+
     statusBar()->hide(); // Hide sizeGrip on default, which comes with statusBar
 
-    editor = new QTextEdit(this);
+    editor = new MyTextEdit(this);
     editor->setFocus();
     editor->setTabStopDistance(20); // unit is pixel, default would be 80
     editor->setAutoFillBackground(true);
@@ -61,26 +65,20 @@ TextEditor::TextEditor(const QString eName)   // FEATURE #137 insert images with
     connect(editor, SIGNAL(currentCharFormatChanged(const QTextCharFormat &)), this,
             SLOT(formatChanged(const QTextCharFormat &)));
 
+    connect(editor, SIGNAL(textChanged()), this, SLOT(editorChanged()));
 
-    QAction *a = new QAction("Close window", this);
-    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    a->setShortcut(Qt::CTRL | Qt::Key_D);
-    connect(a, SIGNAL(triggered()), this, SLOT(closeWindow()));
-    //fileMenu->addAction(a);
-    editor->addAction(a);
-
-    // Load settings
-    init (eName);
+    connect(editor, SIGNAL(editUrlCursor(QTextCursor)), this, SLOT(insertOrEditUrl(QTextCursor)));
     setWindowIcon(QPixmap(":/vym-editor.png"));
 
+    // Load settings
+    init ();
+
     // Various states
-    richTextMode = false;
     blockChangedSignal = false;
     blockTextUpdate = false;
     setInactive();
 
-    editorName = "Text editor";
-    setEditorTitle("");
+    setTitle("");
 
     menuBar()->setNativeMenuBar(false);
 }
@@ -88,7 +86,7 @@ TextEditor::TextEditor(const QString eName)   // FEATURE #137 insert images with
 TextEditor::~TextEditor()
 {
     // Save Settings
-    QString n = QString("/satellite/%1/").arg(shortcutScope);
+    QString n = QString("/satellite/%1/").arg(editorId);
     settings.setValue(n + "geometry/size", size());
     settings.setValue(n + "geometry/pos", pos());
     settings.setValue(n + "state", saveState(0));
@@ -107,11 +105,9 @@ TextEditor::~TextEditor()
     settings.setValue(n + "colors/richTextForeground", colorRichTextForeground.name());
 }
 
-void TextEditor::init(const QString &scope)
+void TextEditor::init()
 {
-    shortcutScope = scope;
-
-    QString n = QString("/satellite/%1/").arg(shortcutScope);
+    QString n = QString("/satellite/%1/").arg(editorId);
     colorRichTextEditorBackground = QColor::fromString(
         settings.value(n + "colors/richTextEditorBackground", vymBaseColor.name()).toString());
 
@@ -136,7 +132,7 @@ void TextEditor::init(const QString &scope)
 
     restoreState(settings.value(n + "state", 0).toByteArray());
 
-    filenameHint = "";
+    fileNameInt = "";
     fixedFontInt = fixedFont;
     varFontInt = varFont;
     QString s =
@@ -159,6 +155,8 @@ void TextEditor::init(const QString &scope)
     clear();
 }
 
+void TextEditor::setFocus() { editor->setFocus(); }
+
 bool TextEditor::isEmpty()
 {
     if (editor->toPlainText().length() > 0)
@@ -167,21 +165,17 @@ bool TextEditor::isEmpty()
         return true;
 }
 
-void TextEditor::setEditorTitle(const QString &s)
+void TextEditor::setTitle(const QString &s)
 {
-    editorTitle = (s.isEmpty()) ? editorName : editorName + ": " + s;
+    QString windowTitle = (s.isEmpty()) ? shortcutScope : shortcutScope + ": " + s;
 
     // Set title of parent dockWidget
     if (parentWidget())
-        parentWidget()->setWindowTitle(editorTitle);
+        parentWidget()->setWindowTitle(windowTitle);
 
-    setWindowTitle(editorTitle);
+    setWindowTitle(windowTitle);
 }
 
-QString TextEditor::getEditorTitle() { return editorTitle; }
-
-void TextEditor::setEditorName(const QString &s) { editorName = s; }
-
 void TextEditor::setFont(const QFont &font)
 {
     blockChangedSignal = true;
@@ -228,28 +222,17 @@ QString TextEditor::getFontHintDefault()
         return "var";
 }
 
-void TextEditor::setFilename(const QString &fn)
+void TextEditor::setFileName(const QString &fn)
 {
-    if (state == filledEditor) {
-        if (fn.isEmpty()) {
-            filename = "";
-            mainWindow->statusMessage(
-                tr("No filename available for this note.", "Statusbar message"));
-        }
-        else {
-            filename = fn;
-            mainWindow->statusMessage(
-                tr(QString("Current filename is %1").arg(filename).toUtf8(),
-                   "Statusbar message"));
-        }
-    }
+    fileNameInt = fn;
 }
 
-QString TextEditor::getFilename() { return filename; }
+QString TextEditor::fileName() { return fileNameInt; }
 
-void TextEditor::setFilenameHint(const QString &fnh) { filenameHint = fnh; }
-
-QString TextEditor::getFilenameHint() { return filenameHint; }
+void TextEditor::setFileNameHint(const QString &fnh)
+{
+    fileNameHintInt = fnh;
+}
 
 QString TextEditor::getText()
 {
@@ -325,8 +308,6 @@ void TextEditor::setTextCursor(const QTextCursor &cursor)
 
 QTextCursor TextEditor::getTextCursor() { return editor->textCursor(); }
 
-void TextEditor::setFocus() { editor->setFocus(); }
-
 void TextEditor::setupFileActions()
 {
     QToolBar *tb = addToolBar(tr("Note Actions"));
@@ -348,21 +329,13 @@ void TextEditor::setupFileActions()
     a = new QAction(QPixmap(QString(":/document-export-%1").arg(iconTheme)), tr("&Export..."), this);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     switchboard.addAction(a, "textSave", Qt::CTRL | Qt::Key_S, shortcutScope, tag);
-    connect(a, SIGNAL(triggered()), this, SLOT(textExport()));
+    connect(a, SIGNAL(triggered()), this, SLOT(textExportAs()));
     tb->addAction(a);
     fileMenu->addAction(a);
     addAction(a);
     filledEditorActions << a;
     actionFileExport = a;
 
-    a = new QAction(tr("Export &As...(ASCII)"), this);
-    switchboard.addAction(a, "textExportAsASCII", shortcutScope, tag);
-    connect(a, SIGNAL(triggered()), this, SLOT(textExportText()));
-    fileMenu->addAction(a);
-    addAction(a);
-    filledEditorActions << a;
-    actionFileExportText = a;
-
     fileMenu->addSeparator();
     a = new QAction(QPixmap(QString(":/document-print-%1.svg").arg(iconTheme)), tr("&Print..."), this);
     switchboard.addAction(a, "textPrint", Qt::CTRL | Qt::Key_P, shortcutScope, tag);
@@ -378,6 +351,13 @@ void TextEditor::setupFileActions()
     tb->addAction(a);
     filledEditorActions << a;
     actionFileDeleteAll = a;
+
+    a = new QAction("Close window", editor);
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    switchboard.addAction(a, "textCloseWindow", Qt::CTRL | Qt::Key_D, shortcutScope, tag);
+    connect(a, SIGNAL(triggered()), this, SLOT(closeWindow()));
+    fileMenu->addAction(a);
+    editor->addAction(a);
 }
 
 void TextEditor::setupEditActions()
@@ -445,12 +425,20 @@ void TextEditor::setupEditActions()
     filledEditorActions << a;
     actionEditPaste = a;
 
+    a = new QAction(QPixmap(QString(":/flag-url.svg")), tr("Insert or edit URL", "TextEditor") + "...", this);
+    editMenu->addAction(a);
+    connect(a, SIGNAL(triggered()), this, SLOT(insertOrEditUrl()));
+    editMenu->addAction(a);
+    editToolBar->addAction(a);
+    filledEditorRichTextActions << a;
+    actionInsertOrEditUrl = a;
+
     a = new QAction(QPixmap(QString(":/insert-image-%1.svg").arg(iconTheme)), tr("Insert image", "TextEditor") + "...", this);
     editMenu->addAction(a);
     connect(a, SIGNAL(triggered()), this, SLOT(insertImage()));
     editMenu->addAction(a);
     editToolBar->addAction(a);
-    filledEditorActions << a;
+    filledEditorRichTextActions << a;
     actionInsertImage = a;
 }
 
@@ -704,16 +692,10 @@ void TextEditor::textLoad()
     }
 }
 
-void TextEditor::closeEvent(QCloseEvent *ce)
-{
-    ce->accept(); // TextEditor can be reopened with show()
-    closeWindow();
-}
-
 bool TextEditor::eventFilter(QObject *obj, QEvent *ev)
 {
+    //qDebug() << "TE::eventFilter  obj=" << obj << " ev=" << ev;
     if (obj == editor) {
-        // qDebug() << "TE::eventFilter   ev=" << ev;
         if (ev->type() == QEvent::FocusIn) {
             //editor->setFrameStyle(QFrame::Box);
             editor->setStyleSheet("QTextEdit {" + editorFocusInStyle + "}");
@@ -763,11 +745,10 @@ void TextEditor::editorChanged()
 void TextEditor::setRichText(const QString &t)
 {
     blockChangedSignal = true;
-    richTextMode = true;
+    editor->setRichTextMode(true);
     editor->setReadOnly(false);
     editor->setHtml(t);
     actionFormatRichText->setChecked(true);
-    actionInsertImage->setEnabled(true);
 
     // Update state including colors
     updateState();
@@ -779,12 +760,11 @@ void TextEditor::setRichText(const QString &t)
 void TextEditor::setPlainText(const QString &t)
 {
     blockChangedSignal = true;
-    richTextMode = false;
+    editor->setRichTextMode(false);
     editor->setReadOnly(false);
 
     editor->setPlainText(t);
     actionFormatRichText->setChecked(false);
-    actionInsertImage->setEnabled(false);
 
     // Reset also text format
     QTextCharFormat textformat;
@@ -842,6 +822,8 @@ void TextEditor::clear()
     editor->clear();
     setState(emptyEditor);
 
+    fileNameInt.clear();
+
     blockChangedSignal = blockChangedOrg;
 }
 
@@ -849,7 +831,6 @@ void TextEditor::closeWindow()
 {
     parentWidget()->hide();
     emit windowClosed();
-    return;
 }
 
 void TextEditor::deleteAll()
@@ -859,11 +840,25 @@ void TextEditor::deleteAll()
 
 void TextEditor::textExportAs()
 {
-    QTextCharFormat f = editor->currentCharFormat();
+    QString text, postfix;
+    if (actionFormatRichText->isChecked()) {
+        text = editor->toHtml();
+        postfix = ".html";
+    } else {
+        text = editor->toPlainText();
+        postfix = ".txt";
+    }
+
+    QString fn;
+    if (fileNameInt.isEmpty())
+        fn = fileNameHintInt + postfix;
+    else
+        fn = fileNameInt;
 
     QString caption = tr("Export Note to single file");
-    QString fn = QFileDialog::getSaveFileName(
-        this, caption, QString(), "VYM Note (HTML) (*.html);;All files (*)",
+
+    fn = QFileDialog::getSaveFileName(
+        this, caption, fn, "VYM Note (HTML) (*.html);VYM Note (Text) (*.txt);All files (*)",
         0, QFileDialog::DontConfirmOverwrite);
 
     if (!fn.isEmpty()) {
@@ -878,80 +873,21 @@ void TextEditor::textExportAs()
             mb.addButton(tr("Cancel"), QMessageBox::RejectRole);
             mb.exec();
             if (mb.clickedButton() != overwriteButton) return;
+        }
 
-            // save
-            filename = fn;
-            textExport();
+        fileNameInt = fn;
+
+        QFile f(fileNameInt);
+        if (!f.open(QIODevice::WriteOnly)) {
+            mainWindow->statusMessage(QString("Could not write to %1").arg(fileNameInt));
             return;
         }
-        else {
-            filename = fn;
-            textExport();
-            return;
-        }
-    }
-    mainWindow->statusMessage(
-        tr("Couldn't export note ", "dialog 'save note as'") + fn);
-}
 
-void TextEditor::textExport()
-{
-    if (filename.isEmpty()) {
-        textExportAs();
-        return;
-    }
+        QTextStream t(&f);
+        t << text;
+        f.close();
 
-    QString text;
-    if (actionFormatRichText->isChecked())
-        text = editor->toHtml();
-    else
-        text = editor->toPlainText();
-
-    QFile f(filename);
-    if (!f.open(QIODevice::WriteOnly)) {
-        mainWindow->statusMessage(QString("Could not write to %1").arg(filename));
-        return;
-    }
-
-    QTextStream t(&f);
-    t << text;
-    f.close();
-
-    editor->document()->setModified(false);
-
-    mainWindow->statusMessage(QString("Note exported as %1").arg(filename));
-}
-
-void TextEditor::textExportText()
-{
-    QString fn, s;
-    if (!filenameHint.isEmpty()) {
-        if (!filenameHint.contains(".txt"))
-            s = filenameHint + ".txt";
-        else
-            s = filenameHint;
-    }
-    else
-        s = QString();
-    QString caption = tr("Export Note to single file (ASCII)");
-    fn = QFileDialog::getSaveFileName(
-        this, caption, s, "VYM Note (ASCII) (*.txt);;All files (*)");
-
-    if (!fn.isEmpty()) {
-        QFile file(fn);
-
-        // Already tested in QFileDialog, if we may overwrite in case file exists already
-
-        if (!file.open(QIODevice::WriteOnly))
-            mainWindow->statusMessage(
-                QString("Could not write to %1").arg(filename));
-        else {
-            QTextStream t(&file);
-            t << getVymText().getTextASCII();
-            file.close();
-
-            mainWindow->statusMessage(QString("Note exported as %1").arg(fn));
-        }
+        mainWindow->statusMessage(QString("Note exported as %1").arg(fileNameInt));
     }
 }
 
@@ -985,6 +921,11 @@ void TextEditor::toggleFonthint()
     emit textHasChanged(getVymText());
 }
 
+bool TextEditor::richTextMode()
+{
+    return editor->richTextMode();
+}
+
 void TextEditor::setRichTextMode(bool b)
 {
     if (b) {
@@ -1215,10 +1156,13 @@ void TextEditor::updateActions()
 
     b = (state == filledEditor && actionFormatRichText->isChecked()) ? true : false;
     foreach (QAction* a, filledEditorRichTextActions)
-        a->setEnabled(b);
+    {
+        a->setEnabled(b); // FIXME-3  Only on Mac not greyed out when disabled. Qt bug? 
+        // qDebug() << "Setting action " << a << " to " << b;
+    }
 
     actionFormatRichText->setEnabled(true);
-    if (richTextMode) {
+    if (richTextMode()) {
         actionFormatUseFixedFont->setEnabled(false);    // FIXME-3 Maybe even hide it in RT mode
         fontToolBar->show();
         formatToolBar->show();
@@ -1308,6 +1252,76 @@ void TextEditor::selectRichTextBackgroundColor()
     setRichTextBackgroundColor(col);
 }
 
+void TextEditor::insertOrEditUrl()
+{
+    insertOrEditUrl(editor->textCursor());
+}
+
+void TextEditor::insertOrEditUrl(QTextCursor cursor)
+{
+    QTextCharFormat fmt = cursor.charFormat();
+    QString url;
+    QString text;
+    bool edit = false;
+    int anchorStart;
+    int anchorEnd;
+
+    if (fmt.isAnchor()) {
+        QString plainText = editor->toPlainText();
+        url = fmt.anchorHref();
+        edit = true;
+
+        // Find beginning of URL in block
+        int pos = cursor.position();
+        int pos_org = pos;
+        anchorStart = pos;
+        while (!cursor.atBlockStart() && pos == anchorStart) {
+            pos--;
+            cursor.setPosition(pos);
+            if (cursor.charFormat().isAnchor())
+                anchorStart = pos;
+        }
+
+        // Find end of URL in block
+        pos = pos_org;
+        anchorEnd = pos;
+        while (!cursor.atBlockEnd() && pos == anchorEnd) {
+            pos++;
+            cursor.setPosition(pos);
+            if (cursor.charFormat().isAnchor())
+                anchorEnd = pos;
+        }
+        text = plainText.slice(anchorStart - 1, anchorEnd - anchorStart + 1);
+    }
+
+    UrlDialog dia (this);
+    dia.setUrl(url);
+    dia.setText(text);
+    if (dia.exec()) {
+        url = dia.url();
+        fmt = cursor.charFormat();
+        if (!url.isEmpty()) {
+            fmt.setAnchor(true);
+            fmt.setAnchorHref(url);
+            fmt.setFontUnderline(true);
+        } else {
+            fmt.setAnchor(false);
+            fmt.setFontUnderline(false);
+        }
+
+        if (edit) {
+            cursor.setPosition(anchorStart - 1);
+            cursor.movePosition(
+                    QTextCursor::NextCharacter, 
+                    QTextCursor::KeepAnchor, 
+                    anchorEnd - anchorStart + 1);
+            cursor.removeSelectedText();
+            cursor.insertText(dia.text(), fmt);
+        } else
+            cursor.insertText(dia.text(), fmt);
+    }
+}
+
 void TextEditor::insertImage()
 {
     QStringList imagePaths = openImageDialog(tr("Load image", "TextEditor"));
