@@ -5,7 +5,8 @@
 #include <QString>
 #include <QtGui>
 #include "vymtext.h"
-class QTextEdit;
+
+class MyTextEdit;
 class QComboBox;
 
 enum EditorState { inactiveEditor, emptyEditor, filledEditor };
@@ -13,22 +14,20 @@ enum EditorState { inactiveEditor, emptyEditor, filledEditor };
 class TextEditor : public QMainWindow {
     Q_OBJECT
   public:
-    TextEditor(const QString eName = "undefinedEditorName");
+    TextEditor(const QString &id, const QString &scope);
     ~TextEditor();
 
-    void init(const QString &ename);
+    void init();
+    void setFocus();
     bool isEmpty();
-    void setEditorName(const QString &);
-    void setEditorTitle(const QString &t = "");
-    QString getEditorTitle();
+    void setTitle(const QString &t = "");
     void setFont(const QFont &);
     void setFontHint(const QString &);
     QString getFontHint();
     QString getFontHintDefault();
-    void setFilename(const QString &);
-    QString getFilename();
-    void setFilenameHint(const QString &);
-    QString getFilenameHint();
+    void setFileName(const QString &);
+    QString fileName();
+    void setFileNameHint(const QString &);
     QString getText();
     VymText getVymText();
 
@@ -36,14 +35,12 @@ class TextEditor : public QMainWindow {
     bool findText(const QString &, const QTextDocument::FindFlags &, int i);
     void setTextCursor(const QTextCursor &cursor);
     QTextCursor getTextCursor();
-    void setFocus();
 
   protected:
     void setupFileActions();
     void setupEditActions();
     void setupFormatActions();
     void setupSettingsActions();
-    void closeEvent(QCloseEvent *);
     bool eventFilter(QObject *obj, QEvent *ev);
 
   public slots:
@@ -69,11 +66,10 @@ class TextEditor : public QMainWindow {
   private slots:
     void textLoad();
     void textExportAs();
-    void textExport();
-    void textExportText();
     void textPrint();
     void textEditUndo();
     void toggleFonthint();
+    bool richTextMode();
     void setRichTextMode(bool b);
     void toggleRichText();
     void setFixedFont();
@@ -99,6 +95,8 @@ class TextEditor : public QMainWindow {
     void selectRichTextEditorBackgroundColor();
     void selectRichTextForegroundColor();
     void selectRichTextBackgroundColor();
+    void insertOrEditUrl();
+    void insertOrEditUrl(QTextCursor);
     void insertImage();
 
   public:
@@ -110,19 +108,16 @@ class TextEditor : public QMainWindow {
 
   protected:
     QString shortcutScope; // used for settings and shortcut scopes
-    QTextEdit *editor;
+    MyTextEdit *editor;
     QPoint lastPos;     // save last position of window
-    QString editorName; // Name of editor, e.g. note editor, heading editor, ...
-    QString editorTitle; // window title: Editor name + selected branch
-    QString filename;
-    QString filenameHint;
+    QString editorId;   // Name of editor, e.g. NoteEditor or HeadingEditor
+    QString fileNameInt;
+    QString fileNameHintInt;    // E.g. heading of branch for notes
 
     EditorState state;
     bool blockChangedSignal;
     bool blockTextUpdate;       // Set *while* textHasChanged is still being emitted
 
-    bool richTextMode;
-
     QColor colorRichTextEditorBackground;
     QColor colorRichTextBackground;
     QColor colorRichTextForeground;
@@ -152,6 +147,7 @@ class TextEditor : public QMainWindow {
         *actionFilePrint, *actionFileDeleteAll, *actionEditUndo,
         *actionEditRedo, *actionEditCopy, *actionEditCut, *actionEditPaste,
         *actionSelectAll,
+	*actionInsertOrEditUrl,
 	*actionInsertImage,
         *actionFormatUseFixedFont, *actionFormatRichText,
         *actionSettingsVarFont, *actionSettingsFixedFont,
