@@ -9,6 +9,7 @@ class VymModelWrapper;
 ///////////////////////////////////////////////////////////////////////////
 class VymWrapper : public QObject {
     Q_OBJECT
+
   public:
     VymWrapper();
     ~VymWrapper();
@@ -18,10 +19,12 @@ class VymWrapper : public QObject {
     bool closeMapWithID(uint n);
     QString currentColor();
     Q_INVOKABLE QObject *currentMap();
+    Q_INVOKABLE QObject *mapWithId(uint n);
     uint currentMapID();
     void editHeading();
     bool directoryIsEmpty(const QString &dirName);
     bool directoryExists(const QString &dirName);
+    void exit();
     bool fileCopy(const QString &srcPath, QString dstPath);
     bool fileExists(const QString &fileName);
     bool fileRemove(const QString &fileName);
@@ -38,7 +41,6 @@ class VymWrapper : public QObject {
     void selectQuickColor(int n);
     void statusMessage(const QString &s);
     void saveFile(const QString &filename, const QString &s);
-    void toggleTreeEditor();
     bool usesDarkTheme();
     QString version();
     QString vymBaseDir();
