@@ -423,7 +423,7 @@ void VymReader::readBranchOrMapCenter(File::LoadMode loadModeBranch, int insertP
             xml.name() == QLatin1String("note"))
             readHeadingOrVymNote();
         else if (xml.name() == QLatin1String("branch")) {
-            if (lastBranch && lastBranch->depth() < 3) {
+            if (lastBranch && lastBranch->depth() < 3 && false) {   // FIXME-2 Updates during load disabled for now. Too many selectionCHanges
                 // Some graphical repainting during loading of map
                 lastBranch->updateVisuals();
                 model->select(lastBranch);
